Release History
===============

**2.1.0 2016-01-06**

*   Added:

    Chart creation

*   Fixed:

    Report file names (removed ':'s to make sure not to conflict with Windows
    rules

**2.0.1 2016-01-01**

*   Changed:

    *   rebuilt from scratch to get rid of the sqlite3 database used in
        version 1.x
    *   now using the hcpsdk
    *   now storing the reports in a folder structure
    *   added possibility to store to HCP

